@@ -73,9 +73,8 @@ else:
         pass
 
 APPNAME = 'PDF Arranger'
-VERSION = '1.6.0'
+VERSION = '1.6.2'
 WEBSITE = 'https://github.com/jeromerobert/pdfarranger'
-LICENSE = 'GNU General Public License (GPL) Version 3.'
 
 # Add support for dnd to other instance and insert file at drop location in Windows
 if os.name == 'nt':
@@ -380,6 +379,7 @@ class PdfArranger(Gtk.Application):
             self.set_accels_for_action("win." + a, [k] if isinstance(k, str) else k)
         # Disable actions
         self.iv_selection_changed_event()
+        self.window_focus_in_out_event()
         self.__update_num_pages(self.iconview.get_model())
         self.undomanager.set_actions(self.window.lookup_action('undo'),
                                      self.window.lookup_action('redo'))
@@ -404,6 +404,8 @@ class PdfArranger(Gtk.Application):
             self.window.maximize()
         self.window.set_default_size(*self.config.window_size())
         self.window.connect('delete_event', self.on_quit)
+        self.window.connect('focus_in_event', self.window_focus_in_out_event)
+        self.window.connect('focus_out_event', self.window_focus_in_out_event)
 
         if hasattr(GLib, "unix_signal_add"):
             GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, signal.SIGINT, self.close_application)
@@ -982,6 +984,7 @@ class PdfArranger(Gtk.Application):
             self.clipboard_default.set_text('pdfarranger-clipboard\n' + data, -1)
 
         self.clear_selected()
+        self.window.lookup_action("paste").set_enabled(True)
 
     def on_action_copy(self, _action, _param, _unknown):
         """Copy selected pages to clipboard."""
@@ -991,6 +994,7 @@ class PdfArranger(Gtk.Application):
             self.clipboard_default.set_text('', -1)
         if os.name == 'nt':
             self.clipboard_default.set_text('pdfarranger-clipboard\n' + data, -1)
+        self.window.lookup_action("paste").set_enabled(True)
 
     def on_action_paste(self, _action, mode, _unknown):
         """Paste pages or files from clipboard."""
@@ -1365,6 +1369,13 @@ class PdfArranger(Gtk.Application):
                      ("split", ne)]:
             self.window.lookup_action(a).set_enabled(e)
 
+    def window_focus_in_out_event(self, _widget=None, _event=None):
+        """Enable or disable paste actions based on clipboard content."""
+        cb_d_data = self.clipboard_default.wait_for_text()
+        cb_p_data = os.name == 'posix' and self.clipboard_pdfarranger.wait_for_text()
+        data_available = True if cb_d_data or cb_p_data else False
+        self.window.lookup_action("paste").set_enabled(data_available)
+
     def sw_dnd_received_data(self, _scrolledwindow, _context, _x, _y,
                              selection_data, target_id, _etime):
         """Handles received data by drag and drop in scrolledwindow"""
@@ -1629,11 +1640,11 @@ class PdfArranger(Gtk.Application):
             '%s is a tool for rearranging and modifying PDF files. '
             'Developed using GTK+ and Python') % APPNAME)
         about_dialog.set_authors(['Konstantinos Poulios'])
-        about_dialog.add_credit_section('Maintainers and contributors', [
+        about_dialog.add_credit_section(_('Maintainers and contributors'), [
             'https://github.com/jeromerobert/pdfarranger/graphs/contributors'])
         about_dialog.set_website_label(WEBSITE)
         about_dialog.set_logo_icon_name(ICON_ID)
-        about_dialog.set_license(LICENSE)
+        about_dialog.set_license(_('GNU General Public License (GPL) Version 3.'))
         about_dialog.connect('response', lambda w, *args: w.destroy())
         about_dialog.connect('delete_event', lambda w, *args: w.destroy())
         about_dialog.show_all()
